@@ -46,6 +46,25 @@ def init(name=None, pwd=None, backend=None):
         # return session
 
 
+def create_app(name, desc):
+    """
+    创建应用
+    :param name: 应用名称
+    :param desc: 应用说明
+    :return: App对象
+    """
+    pass
+
+
+def get_app(app_id):
+    """
+    获取应用
+    :param app_id: 应用ID
+    :return: App对象
+    """
+    pass
+
+
 def create_dataset(name, zone, path, data_type=constants.DataType.TYPE_FILE.value, desc=None):
     """
     创建数据集
@@ -64,36 +83,13 @@ def get_dataset(dataset_id):
     """
     获取数据集对象
     :param dataset_id:数据集ID
-    :return:
+    :return: Dataset对象
     """
     global _backend
     return _backend.get_dataset(dataset_id)
 
 
-def register_model_version(model_id, desc, artifacts, mode=ModelRegisterMode.PYFUNC.value):
-    """
-    注册模型库版本
-    :param model_id: 模型ID
-    :param desc: 备注
-    :param artifacts: 注册文件路径，可以是文件夹,当为docker模式时，此处为docker-image,可以用save命令导出  eg：deployment.tar
-    :param mode: 注册模式,默认为自定义(ModelRegisterMode.PYFUNC.value)
-    :return:
-    """
-    global _backend
-    return _backend.register_model_version(model_id, desc, artifacts, mode)
-
-
-def get_model(model_id):
-    """
-    获取模型对象
-    :param model_id:模型ID
-    :return:
-    """
-    global _backend
-    return _backend.get_model(model_id)
-
-
-def download_dataset_artifact(dataset_id, path, type, destination):
+def download_dataset_artifact(dataset_id, path, destination):
     """
     获取模型对象
     :param dataset_id:数据集ID
@@ -116,3 +112,69 @@ def download_dataset_artifacts(dataset_id, destination):
     """
     global _backend
     return _backend.download_dataset_artifacts(dataset_id, destination)
+
+
+def upload_dataset_artifacts(dataset_id, path):
+    """
+    上传数据集资产文件
+    :param dataset_id: 文件所属数据集
+    :param path: 要上传的文件夹/文件路径
+    :return:  上传文件 succ，共xxx个
+    """
+    global _backend
+    return _backend.upload_dataset_artifacts(dataset_id, path)
+
+
+def create_model(name, desc, app_id):
+    """
+    创建模型
+    # TODO()
+    :param name:模型名称
+    :param desc:模型备注
+    :param app_id:所属应用ID
+    :return:
+    """
+    global _backend
+    pass
+
+
+def get_model(model_id):
+    """
+    获取模型对象
+    :param model_id:模型ID
+    :return:
+    """
+    global _backend
+    return _backend.get_model(model_id)
+
+
+def register_model_version(model_id, desc, artifacts, mode=ModelRegisterMode.PYFUNC.value):
+    """
+    注册模型库版本
+    :param model_id: 模型ID
+    :param desc: 备注
+    :param artifacts: 注册文件路径，可以是文件夹,当为docker模式时，此处为docker-image,可以用save命令导出  eg：deployment.tar
+    :param mode: 注册模式,默认为自定义(ModelRegisterMode.PYFUNC.value)
+    :return:
+    """
+    global _backend
+    return _backend.register_model_version(model_id, desc, artifacts, mode)
+
+
+def get_model_version_by_model(model_id, version):
+    """
+    过模型获取模型库指定信息
+    # TODO()
+    :param model_id: 模型ID
+    :param version:模型版本号
+    :return:
+    """
+
+
+def get_model_version_by_id(model_version_id):
+    """
+    通过模型库ID获取模型库指定信息
+    # TODO()
+    :param model_version_id:模型库ID
+    :return:
+    """
