@@ -27,7 +27,7 @@ from waveletai.model import ModelVersion
 from waveletai.exceptions import LoginFailed, NotADirectory, MissingNameOrPwdException, FileUploadException
 from waveletai.constants import DataType, ModelRegisterMode
 from waveletai.utils.storage_utils import UploadEntry, scan_upload_entries, SilentProgressIndicator, \
-    LoggingProgressIndicator, upload_to_storage
+    LoggingProgressIndicator, upload_to_storage, dataset_upload_to_storage
 from waveletai.utils.datastream import FileStream, FileChunkStream, FileChunk
 
 _logger = logging.getLogger(__name__)
@@ -37,29 +37,70 @@ pool = ThreadPool(9)
 
 class HostedBackend(Backend):
 
-    # @with_api_exceptions_handler
-    # def __init__(self, api_token=None):
-    #     from waveletai import __version__
-    #     self.client_lib_version = __version__
-    #
-    #     self.credentials = Credentials(api_token)
-    #
-    #     ssl_verify = True
-    #     if os.getenv("WAI_ALLOW_SELF_SIGNED_CERTIFICATE"):
-    #         urllib3.disable_warnings()
-    #         ssl_verify = False
-    #
-    #     self._http_client = RequestsClient(ssl_verify=ssl_verify)
-    #     user_agent = 'waveletai-client/{lib_version} ({system}, python {python_version})'.format(
-    #         lib_version=self.client_lib_version,
-    #         system=platform.platform(),
-    #         python_version=platform.python_version())
-    #     self._http_client.session.headers.update({'User-Agent': user_agent})
-    #     self._http_client_for_token.session.headers.update({'User-Agent': user_agent})
-    #     self._http_client.session.headers.update({'X-TOKEN': })
-    #
-    #     self.authenticator = self._create_authenticator(self.credentials.api_token, ssl_verify)
-    #     self._http_client.authenticator = self.authenticator
+    @with_api_exceptions_handler
+    def create_app(self, name, desc):
+        pass
+
+    @with_api_exceptions_handler
+    def get_app(self, app_id):
+        pass
+
+    @with_api_exceptions_handler
+    def update_app(self, app_id, name, desc):
+        pass
+
+    @with_api_exceptions_handler
+    def delete_app(self, app_id):
+        pass
+
+    @with_api_exceptions_handler
+    def update_dataset(self, dataset_id, name, zone, desc):
+        pass
+
+    @with_api_exceptions_handler
+    def delete_dataset(self, dataset_id):
+        pass
+
+    @with_api_exceptions_handler
+    def update_model(self, model_id):
+        pass
+
+    @with_api_exceptions_handler
+    def delete_model(self, model_id):
+        pass
+
+    @with_api_exceptions_handler
+    def get_model_version(self, model_id, version):
+        pass
+
+    @with_api_exceptions_handler
+    def list_model_versions(self, model_id):
+        pass
+
+    @with_api_exceptions_handler
+    def abandon_model_version(self, model_id, version):
+        pass
+
+    @with_api_exceptions_handler
+    def update_model_version(self, model_id, version, desc):
+        pass
+
+    @with_api_exceptions_handler
+    def list_experiments(self, model_id):
+        pass
+
+    @with_api_exceptions_handler
+    def download_model_artifact(self, model_id, path, destination):
+        pass
+
+    @with_api_exceptions_handler
+    def download_model_artifacts(self, model_id, destination):
+        pass
+
+    @with_api_exceptions_handler
+    def list_model_releases(self, model_id, version):
+        pass
+
     @with_api_exceptions_handler
     def __init__(self, name=None, pwd=None):
         if name is None:
@@ -131,30 +172,30 @@ class HostedBackend(Backend):
                        dict['create_time'], dict['type'], dict['create_user_id'], dict['update_time'],
                        dict['update_user_id'])
 
-    @with_api_exceptions_handler
-    def upload_dataset(self, dataset_id, path):
-        """
-        :param dataset_id: 文件所属数据集
-        :param path: 要上传的文件夹/文件路径
-        :return:  上传文件 succ，共xxx个
-        """
-        entries = scan_upload_entries({UploadEntry(path)})
-        s_count = f_count = 0
-        for entry in entries:
-            fs = FileStream(entry)
-            progress_indicator = SilentProgressIndicator(fs.length, fs.filename)
-            prefix = entry.prefix
-            res = self._upload_raw_data(api_method=f'/data/dataset/{dataset_id}/asset', file=fs,
-                                        data={"prefix": prefix.replace('\\', '/')})
-            if res.json()["message"]:
-                f_count = f_count + 1
-                _logger.error(f"file {entry.source_path} upload failed,{res.json()['message']}")
-            else:
-                # print(f"file {entry.source_path} upload succ")
-                progress_indicator.complete()
-                s_count = s_count + 1
-            fs.close()
-        print(f"Dataset id = {dataset_id}  upload succ: {s_count} , fail: {f_count}")
+    # @with_api_exceptions_handler
+    # def upload_dataset(self, dataset_id, path):
+    #     """
+    #     :param dataset_id: 文件所属数据集
+    #     :param path: 要上传的文件夹/文件路径
+    #     :return:  上传文件 succ，共xxx个
+    #     """
+    #     entries = scan_upload_entries({UploadEntry(path)})
+    #     s_count = f_count = 0
+    #     for entry in entries:
+    #         fs = FileStream(entry)
+    #         progress_indicator = SilentProgressIndicator(fs.length, fs.filename)
+    #         prefix = entry.prefix
+    #         res = self._upload_raw_data(api_method=f'/data/dataset/{dataset_id}/asset', file=fs,
+    #                                     data={"prefix": prefix.replace('\\', '/')})
+    #         if res.json()["message"]:
+    #             f_count = f_count + 1
+    #             _logger.error(f"file {entry.source_path} upload failed,{res.json()['message']}")
+    #         else:
+    #             # print(f"file {entry.source_path} upload succ")
+    #             progress_indicator.complete()
+    #             s_count = s_count + 1
+    #         fs.close()
+    #     print(f"Dataset id = {dataset_id}  upload succ: {s_count} , fail: {f_count}")
 
     # @with_api_exceptions_handler
     # def _url_download(self, urls):
@@ -169,6 +210,61 @@ class HostedBackend(Backend):
     #             for data in response.iter_content(chunk_size=chunk_size):
     #                 f.write(data)
     #                 progress.refresh(count=len(data))
+    @with_api_exceptions_handler
+    def upload_dataset_artifacts(self, dataset_id, path):
+        """
+        :param dataset_id: 文件所属数据集
+        :param path: 要上传的文件夹/文件路径
+        :return:  上传文件 succ，共xxx个
+        """
+
+        entries = scan_upload_entries({UploadEntry(path)})
+        dataset_upload_to_storage(entries, self._dataset_upload, self._dataset_chunk_upload_loop,
+                                  warn_limit=CHUNK_SIZE * 1024 * 50, dataset_id=dataset_id)
+
+    @with_api_exceptions_handler
+    # @retrying(stop_max_attempt_number=3)
+    def _dataset_upload(self, entry: UploadEntry, dataset_id):
+        fs = FileStream(entry)
+        progress_indicator = SilentProgressIndicator(fs.length, fs.filename)
+        payload = {"path": entry.prefix.replace('\\', '/'), "dataset_id": dataset_id, 'final': 'true'}
+        res = self._session.post(url=f'{self.api_address}/data/dataset/upload', files=[('file', (
+            fs.filename, fs.fobj, fs.content_type))], data=payload)
+        if res.json()["message"]:
+            _logger.error(f"file {entry.source_path} upload failed,{res.json()['message']}")
+            raise FileUploadException(fs.filename)
+        else:
+            progress_indicator.complete()
+        fs.close()
+
+    @with_api_exceptions_handler
+    # @retrying(stop_max_attempt_number=3)
+    def _dataset_chunk_upload_loop(self, entry: UploadEntry, dataset_id):
+        stream = FileChunkStream(entry)
+        progress_indicator = LoggingProgressIndicator(stream.length, stream.filename)
+        for ind, fc in enumerate(stream.generate(chunk_size=CHUNK_SIZE * 1024 * 20)):
+            self._dataset_chunk_upload(fc, entry.filename, str(ind), entry.prefix.replace('\\', '/'),
+                                       progress_indicator, dataset_id)
+
+        res = self._session.get(url=f'{self.api_address}/data/dataset/upload/success',
+                                params={'filename': entry.filename, 'dataset_id': dataset_id,
+                                        'path': entry.prefix.replace('\\', '/'), 'final': 'true'})
+        if res.json()["message"]:
+            _logger.error(f"file {entry.source_path} upload failed,{res.json()['message']}")
+            raise FileUploadException(entry.filename)
+        else:
+            progress_indicator.complete()
+        stream.close()
+
+    def _dataset_chunk_upload(self, file: FileChunk, filename, chunk, path, progress_indicator, dataset_id):
+        payload = {"chunk": chunk, "path": path, "dataset_id": dataset_id}
+        res = self._session.post(url=f'{self.api_address}/data/dataset/upload', files=[('file', (file.data))],
+                                 data=payload)
+        if res.json()["message"]:
+            _logger.error(f"file {filename} upload failed,{res.json()['message']}")
+            raise FileUploadException(filename + '_' + chunk)
+        else:
+            progress_indicator.progress(file.end - file.start)
 
     @with_api_exceptions_handler
     # @retrying(stop_max_attempt_number=3)
@@ -273,9 +369,9 @@ class HostedBackend(Backend):
                         for res in resultinfo:
                             if asset.name in res:
                                 if '/' in res:
-                                    res = res.split('/' + asset.name)
-                                    res = res[0]
-                                urls.append((asset.path, destination + res, asset.name))
+                                    res_des = res.rsplit('/', 1)
+                                    res_des = res_des[0]
+                                urls.append((asset.path, destination + res_des, asset.name))
                 else:
                     for asset in artifacts:
                         if path in asset.path:
@@ -327,7 +423,9 @@ class HostedBackend(Backend):
                 for asset in artifacts:
                     for res in resultinfo:
                         if res in asset.path:
-                            urls.append((asset.path, destination, asset.name))
+                            res_des = res.rsplit('/', 1)
+                            res_des = res_des[0]
+                            urls.append((asset.path, destination + res_des, asset.name))
                 pool.map(self._url_download, list(set(urls)))
                 pool.close()
                 pool.join()
